@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="fr_FR" sourcelanguage="en_US">
+<!DOCTYPE TS>
+<TS version="2.1" language="fr_FR" sourcelanguage="en_US">
 <context>
     <name>@default</name>
     <message>
@@ -35,9 +36,9 @@ le modifier sous les termes de la Licence Publique Générale GNU telle que
 publiée par la Free Software Foundation, soit la version 2 de la
 Licence, ou (à votre convenance) toute version ultérieure.
 
-Ce programme est distribué dans l&apos;espoir qu&apos;il soit utile,
+Ce programme est distribué dans l'espoir qu'il soit utile,
 mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de
-VALEUR MARCHANDE ou POSSIBILITÉ D&apos;UTILISER POUR UN BUT PARTICULIER.
+VALEUR MARCHANDE ou POSSIBILITÉ D'UTILISER POUR UN BUT PARTICULIER.
 Voyez la licence « GNU General Public License » pour plus de détails.
 
 Vous devriez avoir reçu une copie de la « GNU General Public License »
@@ -80,9 +81,9 @@ le modifier sous les termes de la Licence Publique Générale GNU telle que
 publiée par la Free Software Foundation, soit la version 2 de la
 Licence, ou (à votre convenance) toute version ultérieure.
 
-Ce programme est distribué dans l&apos;espoir qu&apos;il soit utile,
+Ce programme est distribué dans l'espoir qu'il soit utile,
 mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de
-VALEUR MARCHANDE ou POSSIBILITÉ D&apos;UTILISER POUR UN BUT PARTICULIER.
+VALEUR MARCHANDE ou POSSIBILITÉ D'UTILISER POUR UN BUT PARTICULIER.
 Voyez la licence « GNU General Public License » pour plus de détails.
 
 Vous devriez avoir reçu une copie de la « GNU General Public License »
@@ -99,22 +100,22 @@ avec ce programme, sinon voyez à &lt;http://www.gnu.org/licenses/&gt;.
 <context>
     <name>Dialog</name>
     <message>
-        <location filename="../../Ui_about.py" line="97"/>
+        <location filename="../../Ui_about.py" line="98"/>
         <source>About</source>
         <translation type="unfinished">À propos</translation>
     </message>
     <message>
-        <location filename="../../Ui_about.py" line="98"/>
+        <location filename="../../Ui_about.py" line="99"/>
         <source>Authors</source>
         <translation type="unfinished">Auteurs</translation>
     </message>
     <message>
-        <location filename="../../Ui_about.py" line="99"/>
+        <location filename="../../Ui_about.py" line="100"/>
         <source>License</source>
         <translation type="unfinished">Licence</translation>
     </message>
     <message>
-        <location filename="../../Ui_about.py" line="100"/>
+        <location filename="../../Ui_about.py" line="101"/>
         <source>Translations</source>
         <translation type="unfinished">Traductions</translation>
     </message>
@@ -124,17 +125,17 @@ avec ce programme, sinon voyez à &lt;http://www.gnu.org/licenses/&gt;.
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="72"/>
         <source>downloading article and contributor information</source>
-        <translation>téléchargement des informations pour l&apos;article et les contributeurs</translation>
+        <translation>téléchargement des informations pour l'article et les contributeurs</translation>
     </message>
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="74"/>
         <source>parsing article text</source>
-        <translation>analyse du texte de l&apos;article</translation>
+        <translation>analyse du texte de l'article</translation>
     </message>
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="76"/>
         <source>forking threads to download of images and contributor information on them</source>
-        <translation>lancement de threads pour télécharger les images et les information légales qui s&apos;y appliquent</translation>
+        <translation>lancement de threads pour télécharger les images et les information légales qui s'y appliquent</translation>
     </message>
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="78"/>
@@ -144,7 +145,7 @@ avec ce programme, sinon voyez à &lt;http://www.gnu.org/licenses/&gt;.
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="80"/>
         <source>joining threads to download the images and contributor information on them</source>
-        <translation>attente de la fin des threads pour télécharger les images et les information légales qui s&apos;y appliquent</translation>
+        <translation>attente de la fin des threads pour télécharger les images et les information légales qui s'y appliquent</translation>
     </message>
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="82"/>
@@ -184,7 +185,7 @@ avec ce programme, sinon voyez à &lt;http://www.gnu.org/licenses/&gt;.
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="201"/>
         <source>echo &apos;default message; you should not see it&apos;</source>
-        <translation>echo &apos;message par défaut ; vous ne devriez pas le voir&apos;</translation>
+        <translation>echo 'message par défaut ; vous ne devriez pas le voir'</translation>
     </message>
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="325"/>
@@ -195,8 +196,8 @@ avec ce programme, sinon voyez à &lt;http://www.gnu.org/licenses/&gt;.
         <location filename="../../mediawiki2latex-pyqt" line="325"/>
         <source>Please close your PDF viewer before pressing the run button!
 This program need writing permission on the PDF file!</source>
-        <translation>Veuillez fermer votre visionneuse PDF avant d&apos;appuyer sur le bouton de lancement !
-Ce programme a besoin du droit d&apos;écriture sur le fichier PDF !</translation>
+        <translation>Veuillez fermer votre visionneuse PDF avant d'appuyer sur le bouton de lancement !
+Ce programme a besoin du droit d'écriture sur le fichier PDF !</translation>
     </message>
     <message>
         <location filename="../../mediawiki2latex-pyqt" line="334"/>
@@ -229,72 +230,72 @@ Ce programme a besoin du droit d&apos;écriture sur le fichier PDF !</translatio
         <translation>La séquences de procédures est terminée. Vous pouvez fermer la fenêtre.</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="183"/>
+        <location filename="../../Ui_MainWindow.py" line="184"/>
         <source>Mediawiki to LaTeX</source>
         <translation>Mediawiki to LaTeX</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="184"/>
+        <location filename="../../Ui_MainWindow.py" line="185"/>
         <source>Wiki source</source>
         <translation>Source dans le wiki</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="185"/>
+        <location filename="../../Ui_MainWindow.py" line="186"/>
         <source>Template expansion</source>
         <translation>Développement des modèles</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="186"/>
+        <location filename="../../Ui_MainWindow.py" line="187"/>
         <source>Print</source>
         <translation>Print</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="187"/>
+        <location filename="../../Ui_MainWindow.py" line="188"/>
         <source>Mediawiki</source>
         <translation>Mediawiki</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="189"/>
+        <location filename="../../Ui_MainWindow.py" line="190"/>
         <source>Paper</source>
         <translation>Papier</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="190"/>
+        <location filename="../../Ui_MainWindow.py" line="191"/>
         <source>A4</source>
         <translation>A4</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="191"/>
+        <location filename="../../Ui_MainWindow.py" line="192"/>
         <source>A5</source>
         <translation>A5</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="192"/>
+        <location filename="../../Ui_MainWindow.py" line="193"/>
         <source>B5</source>
         <translation>B5</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="193"/>
+        <location filename="../../Ui_MainWindow.py" line="194"/>
         <source>letter</source>
         <translation>letter</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="194"/>
+        <location filename="../../Ui_MainWindow.py" line="195"/>
         <source>legal</source>
         <translation>legal</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="195"/>
+        <location filename="../../Ui_MainWindow.py" line="196"/>
         <source>executive</source>
         <translation>executive</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="196"/>
+        <location filename="../../Ui_MainWindow.py" line="197"/>
         <source>Vector graphics</source>
         <translation>Graphismes vectoriels</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="198"/>
+        <location filename="../../Ui_MainWindow.py" line="199"/>
         <source>Keep vector form</source>
         <translation>Laisser en forme vectorielle</translation>
     </message>
@@ -309,22 +310,22 @@ Ce programme a besoin du droit d&apos;écriture sur le fichier PDF !</translatio
         <translation type="obsolete">exclue</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="204"/>
+        <location filename="../../Ui_MainWindow.py" line="205"/>
         <source>Preferences</source>
         <translation>Préférences</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="205"/>
+        <location filename="../../Ui_MainWindow.py" line="206"/>
         <source>Logs</source>
         <translation>Journaux</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="206"/>
+        <location filename="../../Ui_MainWindow.py" line="207"/>
         <source>Errors</source>
         <translation>Erreurs</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="207"/>
+        <location filename="../../Ui_MainWindow.py" line="208"/>
         <source>Run</source>
         <translation>Lancer</translation>
     </message>
@@ -344,12 +345,12 @@ Ce programme a besoin du droit d&apos;écriture sur le fichier PDF !</translatio
         <translation type="obsolete">Enregistrer les préférences</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="211"/>
+        <location filename="../../Ui_MainWindow.py" line="212"/>
         <source>&amp;Quit (Ctrl-Q)</source>
         <translation>&amp;Quitter (Ctrl-Q)</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="212"/>
+        <location filename="../../Ui_MainWindow.py" line="213"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
@@ -364,7 +365,7 @@ Ce programme a besoin du droit d&apos;écriture sur le fichier PDF !</translatio
         <translation type="obsolete">À propos ... (F1)</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="215"/>
+        <location filename="../../Ui_MainWindow.py" line="216"/>
         <source>F1</source>
         <translation>F1</translation>
     </message>
@@ -401,9 +402,9 @@ le modifier sous les termes de la Licence Publique Générale GNU telle que
 publiée par la Free Software Foundation, soit la version 2 de la
 Licence, ou (à votre convenance) toute version ultérieure.
 
-Ce programme est distribué dans l&apos;espoir qu&apos;il soit utile,
+Ce programme est distribué dans l'espoir qu'il soit utile,
 mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de
-VALEUR MARCHANDE ou POSSIBILITÉ D&apos;UTILISER POUR UN BUT PARTICULIER.
+VALEUR MARCHANDE ou POSSIBILITÉ D'UTILISER POUR UN BUT PARTICULIER.
 Voyez la licence « GNU General Public License » pour plus de détails.
 
 Vous devriez avoir reçu une copie de la « GNU General Public License »
@@ -417,12 +418,12 @@ avec ce programme, sinon voyez à &lt;http://www.gnu.org/licenses/&gt;.
         <translation type="obsolete">Traduction française : ©Georges Khaznadar &lt;georgesk@debian.org&gt; </translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="199"/>
+        <location filename="../../Ui_MainWindow.py" line="200"/>
         <source>Output Format</source>
         <translation>Format cible</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="200"/>
+        <location filename="../../Ui_MainWindow.py" line="201"/>
         <source>PDF</source>
         <translation>PDF</translation>
     </message>
@@ -432,27 +433,27 @@ avec ce programme, sinon voyez à &lt;http://www.gnu.org/licenses/&gt;.
         <translation>ZIP source LaTeX</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="208"/>
+        <location filename="../../Ui_MainWindow.py" line="209"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="209"/>
+        <location filename="../../Ui_MainWindow.py" line="210"/>
         <source>A&amp;bout</source>
         <translation>À &amp;propos</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="210"/>
+        <location filename="../../Ui_MainWindow.py" line="211"/>
         <source>&amp;Save preferences</source>
         <translation>Enregi&amp;strer les préférences</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="213"/>
+        <location filename="../../Ui_MainWindow.py" line="214"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../../Ui_MainWindow.py" line="214"/>
+        <location filename="../../Ui_MainWindow.py" line="215"/>
         <source>&amp;About ... (F1)</source>
         <translation>À &amp;propos ... (F1)</translation>
     </message>
